@@ -80,8 +80,12 @@ typedef unsigned   int uint32_t;
 #define ANTENNA_DV_LEFT  _("[T] Left")
 #define ANTENNA_DV_RIGHT _("[Y] Right")
 
+#define YES _("Yes")
+#define NO _("No")
+
 #define ON _("On")
 #define OFF _("Off")
+
 #define BASIC _("Basic")
 
 #define ANY_KEY _("Press any key to continue.")
@@ -95,7 +99,6 @@ typedef unsigned   int uint32_t;
 #define CREATE_SOCKET_ERROR _("Create socket error. Press any key.")
 #define BIND_SOCKET_ERROR _("Bind socket error. Press any key.")
 
-
 #define MAIN_MENU  _("Back to main menu")
 #define MENU_EXIT _("Exit program")
 #define MENU_SHELL _("Run subshell. To return type 'exit'.")
@@ -136,7 +139,7 @@ typedef unsigned   int uint32_t;
 #define MCOLS 15 /* width of menu window */
 #define LAST_ROW LINES-5
 
-/* Basic distinguished MIB types */
+/* Basic distinguished MIB (and AP) types */
 #define ATMEL410 0
 #define NWN 1
 #define ATMEL12350 2
@@ -261,7 +264,10 @@ struct MacListStat {
     int quality;
     int idle;
     int rssi;
-    
+	unsigned char  Status;
+	unsigned char  Port;
+	unsigned char  ParentMacAddress[6];
+	struct in_addr IP;
 };
 
 /* Function prototypes specific/common for both utilites */
@@ -269,7 +275,7 @@ struct MacListStat {
 /* service */
 extern char * oui2manufacturer(char *);
 extern int ch_list(int, char **);
-void connect_options(unsigned long int, int);
+extern void connect_options(unsigned long int, int);
 extern void about(void);
 extern void draw_menu_win(void);
 extern void main_menu(void);
@@ -285,7 +291,9 @@ extern void get_mac(char *, int, int);
 extern void get_ip(struct in_addr *, int, int, char *);
 extern void get_mask(struct in_addr *, int, int, char *);
 extern void get_value(char *, int, int, int, char, int, int, char *);
+extern void get_pass(char *, int, int, int);
 extern int  menu_choose(int, int, char **, unsigned int);
+extern int  yes_no(int, int);
 extern int  on_off(int, int);
 extern void scroll_rows(struct MacListStat *, int, int, int, int);
 extern void exit_shell(void);
