@@ -28,11 +28,18 @@
 #include "ap-utils.h"
 #include "config.h"
 
+char *ap_types[3] = {
+    "ATMEL410",
+    "NWN",
+    "ATMEL12350"
+};
+
 WINDOW *win_for_menu, *sub_for_menu, *win_for_help, *main_win, *main_sub;
 short ap_type;
 char *community;
-int sockfd;
+int sockfd, atmel410_filter=0;
 struct in_addr ap_ip;
+char *prog_title = "Wireless Access Point Configurator";
 
 void config_menu()
 {
