@@ -32,7 +32,7 @@
 #include <unistd.h>
 
 #define ERR_STR_V "\n\n-\n\n"
-#define ERR_STR_N "999999999\n99999999\n-\n\n"
+#define ERR_STR_N "999999999\n999999999\n-\n\n"
 
 short ap_type = ATMEL410;
 char *community = NULL;
@@ -43,7 +43,7 @@ void usage()
 {
     printf(_("\nUsage:\n"));
     printf(_
-	   ("\tap-mrtg -i ip -c community -t type [-b bssid] [-v] [-h] [-r]\n\n"));
+          ("\tap-mrtg -i ip -c community -t type [-b bssid] [-n name] [-a aptype] [-v] [-h] [-r]\n\n"));
     printf(_
 	   ("Get stats from AP and return it in MRTG parsable format\n\n"));
     printf(_("-i ip        - AP ip address\n"));
@@ -52,11 +52,13 @@ void usage()
 	   ("-t type      - statistics type <w>ireless, <e>thernet, associated <s>tations or <l>ink quality in client mode\n"));
     printf(_
 	   ("-b bssid     - mac address of the AP to which get link quality, only if type=l\n"));
+    printf(_("-n name     - AP name - for check only\n")); 
+    printf(_("-a aptype        - AP type - 410 (default) or 510 for ATMEL12350's, like the ME-102\n"));
     printf(_
 	   ("-v           - report MRTG about problems connecting to AP\n"));
     printf(_("-r           - reset AP when getting LinkQuality stats\n"));
     printf(_("-h           - print this help screen\n\n"));
-    printf(_("ap-mrtg %s Copyright (c) 2002 Roman Festchook\n\n"),
+    printf(_("ap-mrtg %s Copyright (c) 2002-2003 Roman Festchook\n\n"),
 	   VERSION);
 
 }
@@ -115,8 +117,8 @@ int main(int argc, char **argv)
     struct WirelessStatistics *WirelessStat = NULL;
     varbind varbinds[2];
     int i, reset_flag=0;
-    char message[12], bssid_flag, stat_type = 0, *ERR_STR =
-	ERR_STR_N, *bssid = NULL;
+    char message[12], bssid_flag,  stat_type = 0, *ERR_STR =
+	ERR_STR_N, *bssid = NULL, *name = NULL;
     struct sockaddr_in client;
 
 #ifdef HAVE_GETTEXT
@@ -137,7 +139,7 @@ int main(int argc, char **argv)
 
     do {
 	opterr = 0;
-	switch (opt = getopt(argc, argv, "i:c:t:b:rv")) {
+	switch (opt = getopt(argc, argv, "i:c:t:b:n:a:rv")) {
 	case 'i':
 	    if (inet_aton(optarg, &ap_ip) == 0) {
 		printf(_("Invalid IP-address\n"));
@@ -158,9 +160,37 @@ int main(int argc, char **argv)
 	    bssid = malloc(strlen(optarg) + 1);
 	    strncpy(bssid, optarg, strlen(optarg) + 1);
 	    break;
+	case 'n':
+	    name = malloc(strlen(optarg) + 1);
+	    strncpy(name, optarg, strlen(optarg) + 1);
+	    break;
 	case 'r':
 	    reset_flag=1;
 	    break;
+        case 'a':
+            if ( strcmp( optarg, "510\0" ) == 0) {
+              Wireless[5] = 0xE0;
+              Wireless[6] = 0x3E;
+              EthRx[5] = 0xE0;
+              EthRx[6] = 0x3E;
+              EthTx[5] = 0xE0;
+              EthTx[6] = 0x3E;
+              operAccessPointName[5] = 0xE0;
+              operAccessPointName[6] = 0x3E;
+              StasNum[5] = 0xE0;
+              StasNum[6] = 0x3E;
+              KnownAP[5] = 0xE0;
+              KnownAP[6] = 0x3E;
+              bridgeOperationalMode[5] = 0xE0;
+              bridgeOperationalMode[6] = 0x3E;
+            } else if (strcmp(optarg, "410") == 0) {
+              /* nothing - hard-coded defaults are fine */
+            } else {
+              /* Invalid AP-Type */
+              printf(_("Invalid AP-Type '%s' - valid types are 510 or 410\n"), optarg);
+              return 1;
+            }
+            break;
 	case -1:
             break;
 	default:
@@ -344,6 +374,7 @@ int main(int argc, char **argv)
     }
 
     printf("-\n");
+
     varbinds[0].oid = operAccessPointName;
     varbinds[0].len_oid = sizeof(operAccessPointName);
     varbinds[0].len_val = 0;
@@ -352,11 +383,17 @@ int main(int argc, char **argv)
 	printf("\n");
 	return 1;
     }
+
     for (i = 0; i < 32 && *(varbinds[0].value + i); i++)
 	putchar(*(varbinds[0].value + i));
     putchar('\n');
     close(sockfd);
 
+    if ( name != NULL ) 
+      if (strncmp(name,varbinds[0].value,strlen(name)) ){
+	return 2;
+      }
+    
   quit:
     if (community)
 	free(community);
@@ -364,6 +401,8 @@ int main(int argc, char **argv)
 	free(app);
     if (bssid)
 	free(bssid);
+    if (name)
+	free(name);
     return 0;
 }
 
