@@ -17,19 +17,12 @@
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
+#include <stdlib.h>
+#include <unistd.h>
+#include <string.h>
+#include <ncurses.h>
 #include "ap-utils.h"
-#include <ncurses.h>
-#include <stdio.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <stdlib.h>
-#include <string.h>
-#include <ncurses.h>
-#include <stdio.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <stdlib.h>
-#include <string.h>
 
 #define MAX_LINES LINES-6
 #define PACKET_ERROR _("AuthorizedMacTableString packet error")
@@ -161,7 +154,7 @@ void atmel_auth_mac()
 	    goto quit;
 	case 'a':
 	case 'A':
-	    auth_mac = on_off(strlen(MAC_AUTH), 0);
+	    auth_mac = on_off(0, strlen(MAC_AUTH));
 	    clear_main_new(0, 1);
 	    print_menusel(0, 0, MAC_AUTH, (auth_mac == 1) ? ON : OFF);
 	    m_authmac = 1;
@@ -272,7 +265,6 @@ void atmel_auth_mac()
 		end++;
 		scroll_rows(first, begin, end, 3, 0);
 	    }
-
 	    continue;
 	case KEY_UP:
 	case KEY_LEFT:
@@ -408,7 +400,7 @@ void nwn_auth_mac()
 	case 'q':
 	    goto quit;
 	case 'a':
-	    auth_mac = on_off(strlen(MAC_AUTH), 0) - 1;
+	    auth_mac = on_off(0, strlen(MAC_AUTH)) - 1;
 	    clear_main_new(0, 1);
 	    print_menusel(0, 0, MAC_AUTH, (auth_mac) ? OFF : ON);
 	    continue;
