@@ -36,8 +36,8 @@
 #define CF_PORT _("[C] Configuration-enabled port(s): ")
 #define TRAP_PORT _("[T] Trap-sending port(s): ")
 #define FW_BCAST _("[R] Forward broadcast traffic: ")
-#define SB_BCAST _("[B] Send back broadcast traffic: ")
-#define SB_UCAST _("[U] Send back unicast traffic: ")
+#define SB_BCAST _("[B] Isolate wireless clients (broadcast traffic): ")
+#define SB_UCAST _("[U] Isolate wireless clients (unicast traffic): ")
 #define HELP _("INGFPDOMSCTRBU - set; W - write conf; Q - quit to menu")
 
 extern short ap_type;
@@ -329,7 +329,7 @@ void bridging()
 	    continue;
 	case 'F':
 	case 'f':
-	    filter = on_off(strlen(IP_FILTER), 3);
+	    filter = on_off(3, strlen(IP_FILTER));
 	    clear_main_new(3, 4);
 	    print_menusel(3, 0, IP_FILTER, (filter == 1) ? ON : OFF);
 	    m_filter = 1;
@@ -337,7 +337,7 @@ void bridging()
 	case 'P':
 	case 'p':
 	    if (!IS_ATMEL410_SBRIDGES) {
-		primary_port = menu_choose(strlen(PR_PORT), 4, pr_ports, 2) + 1;
+		primary_port = menu_choose(4, strlen(PR_PORT), pr_ports, 2) + 1;
 		clear_main_new(4, 5);
 		print_menusel(4, 0, PR_PORT, pr_ports[primary_port - 1]);
 		m_primary_port = 1;
@@ -345,14 +345,14 @@ void bridging()
 	    continue;
 	case 'D':
 	case 'd':
-	    dhcp = on_off(strlen(DHCP), 5);
+	    dhcp = on_off(5, strlen(DHCP));
 	    clear_main_new(5, 6);
 	    print_menusel(5, 0, DHCP, (dhcp == 1) ? ON : OFF);
 	    m_dhcp = 1;
 	    continue;
 	case 'O':
 	case 'o':
-	    bridge_mode = menu_choose(strlen(OPER), 6, bridge_modes, 5) + 1;
+	    bridge_mode = menu_choose(6, strlen(OPER), bridge_modes, 5) + 1;
 	    clear_main_new(6, 8);
 	    print_menusel(6, 0, OPER, bridge_modes[bridge_mode - 1]);
 	    if (bridge_mode != 2) {
@@ -369,6 +369,9 @@ void bridging()
 	    continue;
 	case 'M':
 	case 'm':
+	    if (bridge_mode == 2)
+		continue;
+
 	    get_mac(RemoteBSSID, 7, strlen(REMOTE_MAC));
 /*	    mvwaddstr(main_sub, 7, 21, "  :  :  :  :  :  ");
 	    for (i = 0; i < 6; i++) {
@@ -384,7 +387,7 @@ void bridging()
 	    continue;
 	case 'S':
 	case 's':
-	    traps = on_off(strlen(TRAPS), 8);
+	    traps = on_off(8, strlen(TRAPS));
 	    clear_main_new(8, 9);
 	    print_menusel(8, 0, TRAPS, (traps == 1) ? ON : OFF);
 	    m_traps = 1;
@@ -392,10 +395,8 @@ void bridging()
 	case 'C':
 	case 'c':
 	    if (ap_type == ATMEL12350) {
-		config_port = menu_choose(strlen(CF_PORT), 9, cf_trap_ports, 3)
-			+ 1;
+		config_port = menu_choose(9, strlen(CF_PORT), cf_trap_ports, 3);
 		clear_main_new(9, 10);
-		config_port--;
 		print_menusel(9, 0, CF_PORT, cf_trap_ports[config_port]);
 		m_config_port = 1;
             }
@@ -412,7 +413,7 @@ void bridging()
 	case 'R':
 	case 'r':
 	    if (ap_type == ATMEL12350) {
-		fw_bcast = on_off(strlen(FW_BCAST), 11);
+		fw_bcast = on_off(11, strlen(FW_BCAST));
 		clear_main_new(11, 12);
 		print_menusel(11, 0, FW_BCAST, (fw_bcast == 1) ? ON : OFF);
 		m_fw_bcast = 1;
@@ -421,7 +422,7 @@ void bridging()
 	case 'B':
 	case 'b':
 	    if (ap_type == ATMEL12350) {
-		sb_bcast = on_off(strlen(SB_BCAST), 12);
+		sb_bcast = on_off(12, strlen(SB_BCAST));
 		clear_main_new(12, 13);
 		print_menusel(12, 0, SB_BCAST, (sb_bcast == 1) ? ON : OFF);
 		m_sb_bcast = 1;
@@ -430,7 +431,7 @@ void bridging()
 	case 'U':
 	case 'u':
 	    if (ap_type == ATMEL12350) {
-		sb_ucast = on_off(strlen(SB_UCAST), 13);
+		sb_ucast = on_off(13, strlen(SB_UCAST));
 		clear_main_new(13, 14);
 		print_menusel(13, 0, SB_UCAST, (sb_ucast == 1) ? ON : OFF);
 		m_sb_ucast = 1;
@@ -509,7 +510,7 @@ void bridging()
 		varbinds[i].type = INT_VALUE;
 		i++;
 	    }
-	    if (bridge_mode != 2 && m_remote_bssid) {
+	    if (m_remote_bssid) {
 		varbinds[i].oid = bridgeRemoteBridgeBSSID;
 		varbinds[i].len_oid = sizeof(bridgeRemoteBridgeBSSID);
 		varbinds[i].value = RemoteBSSID;
