@@ -18,13 +18,12 @@
  *
  */
 
-#include "ap-utils.h"
 #include <stdlib.h>
+#include <unistd.h>
 #include <ncurses.h>
 #include <menu.h>
-#include <string.h>
-#include <sys/types.h>
-#include <unistd.h>
+#include "ap-utils.h"
+
 #define RATES_RECORD "[%d]   %02.1fM\t%s"
 
 void advanced()
